@@ -1,7 +1,7 @@
 fn main() {}
 
 #[test_strategy::proptest]
-fn arg(x: u8) {}
+fn arg(#[allow(unused)] x: u8) {}
 
 #[test_strategy::proptest(cases = 100)]
-fn arg_and_config(x: u8) {}
+fn arg_and_config(#[allow(unused)] x: u8) {}
