@@ -1,3 +1,4 @@
+#![warn(clippy::shadow_unrelated)]
 #![allow(clippy::derive_partial_eq_without_eq)]
 mod test_helpers;
 
@@ -159,6 +160,13 @@ fn strategy_rank3() {
     );
 }
 
+#[test]
+fn tuple_struct_strategy() {
+    #[derive(Arbitrary, Debug, PartialEq)]
+    struct X(#[strategy(1..10u32)] u32);
+    assert_arbitrary((1..10u32).prop_map(X));
+}
+
 #[test]
 fn strategy_underline() {
     #[derive(Arbitrary, Debug, PartialEq)]
@@ -1702,3 +1710,14 @@ fn filter_with_strategy_and_map_1() {
 
     assert_arbitrary(s);
 }
+
+macro_rules! macro_rules_arbitrary {
+    ($item:item) => {
+        #[derive(Debug, Arbitrary)]
+        $item
+    };
+}
+macro_rules_arbitrary! {
+    #[allow(unused)]
+    struct MacroRulesArbitrary(#[strategy(0..2)] i32);
+}
